==> jags_0.20.2.orig.tar.gz: jags-0.20.2.orig/src/jags.h <==
/*
 **  Jags v0.1
 **  Copyright (C) 2000 Daniel Sundberg
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation; either version 2 of the License, or
 **  (at your option) any later version.
 **
 **  This program is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 **
 ** jags.h
 ** 
 ** Made by:    Daniel Sundberg
 ** E-Mail:     dansun-8@student.luth.se
 ** Homepage:   http://sumpan.campus.luth.se
 ** 
 ** Started on  Wed Jul  5 19:42:00 2000 Daniel Sundberg 
 ** Last update Fri May 18 00:58:00 2001 Daniel Sundberg
 */

#ifndef __JAGS_H
#define __JAGS_H

#define VERSION      "0.20.2"
#define PROGRAM_NAME "Jags"
#define AUTHOR       "Daniel Sundberg"
#define EMAIL        "dansun-8@student.luth.se"
#define HOMEPAGE     "http://sumpan.campus.luth.se/software/jags"
#define STARTEDON    "Mon Jul  3 20:00:00 2000"  
#define LASTUPDATE   "Sun Jul 15 15:02:00 2001" 

#define INFO         "This program is free software; you can redistribute it and/or modify\n"\
"it under the terms of the GNU General Public License as published by\n"\
"the Free Software Foundation; either version 2 of the License, or\n"\
"(at your option) any later version.\n"\
"\n"\
"This program is distributed in the hope that it will be useful,\n"\
"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"\
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"\
"GNU General Public License for more details.\n"\
"\n"\
"You should have received a copy of the GNU General Public License\n"\
"along with this program; if not, write to the Free Software\n"\
"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"

#endif

==> jags_0.22.1.orig.tar.gz: jags-0.22.1/src/jags.h <==
/*
 **  Copyright (C) 2000-2003 Daniel Sundberg <sumpan@sumpan.com>
 **
 **  This program is free software; you can redistribute it and/or modify
 **  it under the terms of the GNU General Public License as published by
 **  the Free Software Foundation; either version 2 of the License, or
 **  (at your option) any later version.
 **
 **  This program is distributed in the hope that it will be useful,
 **  but WITHOUT ANY WARRANTY; without even the implied warranty of
 **  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 **  GNU General Public License for more details.
 **
 **  You should have received a copy of the GNU General Public License
 **  along with this program; if not, write to the Free Software
 **  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 **
 ** Jags contact information:
 ** Made by:    Daniel Sundberg
 ** E-Mail:     sumpan@sumpan.com
 ** Homepage:   http://jags.sf.net
 ** 
 ** ChangeLog:
 **
 */

#ifndef __JAGS_H
#define __JAGS_H

#define VERSION      "0.22.1"
#define PROGRAM_NAME "Jags"
#define AUTHOR       "Daniel Sundberg"
#define EMAIL        "sumpan@sumpan.com"
#define HOMEPAGE     "http://jags.sf.net"
#define STARTEDON    "Mon Jul  3 20:00:00 2000"  
#define LASTUPDATE   "Thu Sep  4 23:12:00 2003" 

#define INFO         "This program is free software; you can redistribute it and/or modify\n"\
"it under the terms of the GNU General Public License as published by\n"\
"the Free Software Foundation; either version 2 of the License, or\n"\
"(at your option) any later version.\n"\
"\n"\
"This program is distributed in the hope that it will be useful,\n"\
"but WITHOUT ANY WARRANTY; without even the implied warranty of\n"\
"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"\
"GNU General Public License for more details.\n"\

#endif
